#!/bin/sh

set -e
tmpfile=$(mktemp)

## Messages
title="NComputing key import"
msg_success="Key successfully imported."
msg_error="Problems importing key.
You can optionally run this script with '-vv', which will be passed to 'rpm --importkey'."

## Remove old keys
echo "Removing old keys..."
#rpm -qa gpg-pubkey | 
#	while read key; do 
#		rpm -qi $key | 
#			grep -q 'NComputing' && 
#				rpm --allmatches -e $key; 
#	done


## Import public key
echo "Importing new key..."
cat > $tmpfile << EOF
-----BEGIN PGP PUBLIC KEY BLOCK-----
Version: GnuPG v1.4.6 (GNU/Linux)

mQGiBEcVyysRBACmPB6Mudpmb5uszh9YRldIGqVNm7gOum7gQnGyOLCauyAnhabr
qQvzlj0IKiS0X/sWxZ+/oyeyvY9oJjl8EfenAuMbs0v0RKB1my7wvG5bjjAYZiZ5
OAe+ATG72QkJflLPDyL9oLPpXrvW6/Y8kCX/86TCV2RPTP96RH/98wYobwCgpQZT
n5owVwU7G8AaLztw7KFmwDsEAIHurKWhV+t7LeBo8TLWLmOp5mWQepQmT15qd9xt
/6MXzMJ3KSE8QksW5ZcfWOND9Jxo2+pmdy19tMKlavXoomUvffNnOvEimGN1NfxX
rH3laN279PHhAF/7fmUXIQp6ov8VW/XNFL472gOk+N6yq3GzioJ/O+jbE67/lczR
KbJvA/wIWVudaPaUB2rEVgPD0urVgKVOkW0BWVA1Tjd2GFT8sC4+XnqTtm2CXIne
f68S3dBBZQT8594Ie2ZC7sUmNSfvERAsPF3ySroX1tnDE+WN9Ns2eFPC9mdeDaip
Q1e5VXikKRguvFGrFg7j7Hrg6xru5TqYjMXQSaklFbMvQbgZvLRKTkNvbXB1dGlu
ZywgSW5jLiAoTkNvbXB1dGluZyBwYWNrYWdlIHNpZ25pbmcga2V5KSA8c3VwcG9y
dEBuY29tcHV0aW5nLmNvbT6IYAQTEQIAIAUCRxXLKwIbAwYLCQgHAwIEFQIIAwQW
AgMBAh4BAheAAAoJEO7D9sYfsQ4RZ1AAniO5q63/o7ybcwVwcuG8b0eZVOfsAJ9S
zEksDmWzPdNzqaNI+6/xH7Wc8bQjTkNvbXB1dGluZyA8c3VwcG9ydEBuY29tcHV0
aW5nLmNvbT6IYAQTEQIAIAUCRxYrWQIbAwYLCQgHAwIEFQIIAwQWAgMBAh4BAheA
AAoJEO7D9sYfsQ4RSTUAoKEXtUkbv7LqflW2dzD/5mf44yjSAJ9xkA0NU59lhWO8
AVbKw48oYYKlGLkCDQRHFctBEAgArBRX9LfBsqzKQYHJ0qr9EkO9ajoaN/iq7YXy
uxNth37CvmiwLz6JdwWxJU97vcJmAG4uFoKrR/IZs21MsaxSMejwAQvKIwRWXG+E
jIhLcFPjbmG0mKzEyx5xdKK9UQO+nXGMBn2SLB2Q+Kwn0OeoKlbSO4QwKV6IIewe
rh6BrHNTQKEB8An10HjbGQcrNph3FQ+jnTSB4eIHCf/N7w1xf8v6yN5sydhhgbvI
sGEXRPyHThgMG1ImF1HYU3PL+cl+i93eonTuwva1xxYvfFq7u7J4OXryM4jIIgNK
ppZd1vo4DZOSuFu6R3WH9wJDxEi5pJCKKtQziQraEtKQb5eEUwADBQf6AwYETHHn
YRa9fi1csXg5o1i3//Z65gJwXllQbLUg4vbtfpnpcEht+TWu9Lrubq6f6A/W9Xo9
qtxdDe/tCo6qWmnBGha8rLVNI2VlM+NVl8z7OGMCM37trIzPfPxDk8x9BDAhyGaH
ugfw2VSw9lP578xGqiYBG6G+fFInkDRY5xwTx/x9ieLp6b/XyErTREz6SMETvmJr
S/YNCmTJ0RPdQ4VcK+W3OXguQKiKR3nuZ8AZIvO5O3pb2YOkOjUSkrlvkcbti+rx
GO2BIAMPacxEgN5vuQmktPc52eV65oEVCJOID2XAzQSgAb9Kg1dh1C5xtWStTUru
xapU9dOdoBZ2k4hJBBgRAgAJBQJHFctBAhsMAAoJEO7D9sYfsQ4Rl8AAmwewU36N
es54xL21292gFv+qN6oPAJ49lzaWU3hIaaUjCorVjbSCI9lE0A==
=napN
-----END PGP PUBLIC KEY BLOCK-----
EOF

## Actual import
echo rpm "$@" --import $tmpfile && msg="$msg_success" || msg="$msg_error"
rpm "$@" --import $tmpfile && msg="$msg_success" || msg="$msg_error"

## Notification messages
if [ -n "$DISPLAY" ]; then
	if which zenity &>/dev/null; then
		zenity --title="$title" --info --text="$msg"
	else
		if which dialog &>/dev/null; then
			dialog --title "$title" --msgbox "$msg" 20 70
		fi
	fi
else
	if which dialog &>/dev/null; then
		dialog --title "$title" --msgbox "$msg" 20 70
	else
		echo "$msg"
	fi
fi

rm -f $tmpfile

